<?php
$theguide_redux_demo = get_option('redux_demo');

//Custom fields:
require_once get_template_directory() . '/framework/wp_bootstrap_navwalker.php';
require_once get_template_directory() . '/framework/class-ocdi-importer.php';
//Define Text Doimain
$lang = get_template_directory_uri() . '/languages';
load_theme_textdomain('theguide', $lang);

//Theme Set up:
function theguide_theme_setup() {
    /*
     * This theme uses a custom image size for featured images, displayed on
     * "standard" posts and pages.
     */
	add_theme_support( 'custom-header' ); 
	add_theme_support( 'custom-background' );
	
    add_theme_support( 'post-thumbnails' );
    // Adds RSS feed links to <head> for posts and comments.
    add_theme_support( 'automatic-feed-links' );
    // Switches default core markup for search form, comment form, and comments
    // to output valid HTML5.
    add_theme_support( 'title-tag' );
    add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list' ) );
    //Post formats

    add_post_type_support( 'post', 'post-formats', array( 'audio',  'gallery', 'image', 'video' ) );
    add_post_type_support( 'portfolio', 'post-formats', array( 'gallery', 'image' ) );
    // This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
    'primary' =>  esc_html__( 'Primary Navigation Menu: Chosen menu in Home page, single, blog, pages ...', 'theguide' ),
    'navigation1' =>  esc_html__( 'Navigation Menu 1: Chosen menu in Page Navigation 1', 'theguide' ),
    'navigation2' =>  esc_html__( 'Navigation Menu 2: Chosen menu in Page Navigation 2', 'theguide' ),
    'navigation3' =>  esc_html__( 'Navigation Menu 3: Chosen menu in Page Navigation 3', 'theguide' ),
    'navigation4' =>  esc_html__( 'Navigation Menu FAQ: Chosen menu in Page FAQ', 'theguide' ),
    'footer-menu' =>  esc_html__( 'Footer Navigation Menu: Chosen menu in Footer', 'theguide' ),
	) );
    // This theme uses its own gallery styles.
}
add_action( 'after_setup_theme', 'theguide_theme_setup' );
if ( ! isset( $content_width ) ) $content_width = 900;
 
function theguide_fonts_url() {
    $font_url = '';

    if ( 'off' !== _x( 'on', 'Google font: on or off', 'theguide' ) ) {
        $font_url = add_query_arg( 'family', urlencode( 'Raleway:300,400,500,600,800%7COpen+Sans:300,400,500,600,700,800%7CMontserrat:400,700&subset=latin,latin-ext' ), "//fonts.googleapis.com/css" );
    }
    return $font_url;
}

function theguide_theme_scripts_styles() {
	$theguide_redux_demo = get_option('redux_demo');
	$protocol = is_ssl() ? 'https' : 'http';
    wp_enqueue_style( 'theguide-app-min-css', get_template_directory_uri().'/assets/css/app.min.css');
    wp_enqueue_style( 'theguide-custom-css', get_template_directory_uri().'/assets/css/custom.css');
    wp_enqueue_style( 'theguide-fonts', theguide_fonts_url(), array(), '1.0.0' );
    wp_enqueue_style( 'theguide-style', get_stylesheet_uri(), array(), '2016-03-28' ); 
  	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
      wp_enqueue_script( 'comment-reply' );
    //Javascript 
    if(is_page_template('page-templates/template-home.php') or is_page_template('page-templates/other-page.php')){
      wp_enqueue_script('theguide-total', get_template_directory_uri().'/assets/js/total.js',false,true);
    }
}
add_action( 'wp_enqueue_scripts', 'theguide_theme_scripts_styles' ); 

//Custom Excerpt Function
function theguide_do_shortcode($content) {
    global $shortcode_tags;
    if (empty($shortcode_tags) || !is_array($shortcode_tags))
        return $content;
    $pattern = get_shortcode_regex();
    return preg_replace_callback( "/$pattern/s", 'do_shortcode_tag', $content );
}



// Widget Sidebar
function theguide_widgets_init() {
	register_sidebar( array(
        'name'          => esc_html__( 'Primary Sidebar', 'theguide' ),
        'id'            => 'sidebar-1',        
		'description'   => esc_html__( 'Appears in the sidebar section of the site.', 'theguide' ),        
		'before_widget' => '<div id="%1$s" class="widget widget_categories widget-body %2$s">',        
		'after_widget'  => '</div> ',        
		'before_title'  => '<h5 class="widget-title">',        
		'after_title'   => '</h5> '
    ) ); 
}
add_action( 'widgets_init', 'theguide_widgets_init' );

//function tag widgets
function theguide_tag_cloud_widget($args) {
	$args['number'] = 0; //adding a 0 will display all tags
	$args['largest'] = 18; //largest tag
	$args['smallest'] = 11; //smallest tag
	$args['unit'] = 'px'; //tag font unit
	$args['format'] = 'list'; //ul with a class of wp-tag-cloud
	$args['exclude'] = array(20, 80, 92); //exclude tags by ID
	return $args;
}
add_filter( 'widget_tag_cloud_args', 'theguide_tag_cloud_widget' );
function theguide_excerpt() {
  $theguide_redux_demo = get_option('redux_demo');
  if(isset($theguide_redux_demo['blog_excerpt'])){
    $limit = $theguide_redux_demo['blog_excerpt'];
  }else{
    $limit = 80;
  }
  $excerpt = explode(' ', get_the_excerpt(), $limit);
  if (count($excerpt)>=$limit) {
    array_pop($excerpt);
    $excerpt = implode(" ",$excerpt).'...';
  } else {
    $excerpt = implode(" ",$excerpt);
  }
  $excerpt = preg_replace('`[[^]]*]`','',$excerpt);
  return $excerpt;
}


//pagination
if ( !function_exists('theguide_pagination') ) {
  function theguide_pagination() {
    if ( $GLOBALS['wp_query']->max_num_pages < 2 ) {
      return '';
    } ?>
      <?php if ( get_next_posts_link() ) : ?>
        <li class="previous"><?php next_posts_link( esc_html__('Older posts', 'theguide') ); ?></li>
      <?php endif; ?>
      <?php if ( get_previous_posts_link() ) : ?>
        <li class="next"><?php previous_posts_link( esc_html__('Newer posts', 'theguide') ); ?></li>
      <?php endif; ?>
  <?php }
}

function theguide_search_form( $form ) {
    $form = '
  <form  method="get" class="search-form" action="' . esc_url(home_url('/')) . '"> 
            <input type="search" class="form-control" placeholder="'.esc_attr__('Search...', 'theguide').'" value="' . get_search_query() . '" name="s" id="s"> 
  </form>
	';
    return $form;
}
add_filter( 'get_search_form', 'theguide_search_form' );
//Custom comment List:

// Comment Form
function theguide_theme_comment($comment, $args, $depth) {
    //echo 's';
   $GLOBALS['comment'] = $comment; ?>
      <li class="comment">
        <div class="comment-body">
          <div class="comment-author">
            <?php echo get_avatar($comment,$size='80' ); ?>
            <cite class="fn"><?php printf( esc_html__('%s','theguide'), get_comment_author_link()) ?> </cite><br>
            <p class="comment-date"><?php $d = "F d , Y"; printf(get_comment_date($d)) ?></p>
          </div>

          <div class="comment-text">
            <p><?php comment_text() ?></p>
          </div>

          <div class="reply">
            <?php comment_reply_link(array_merge( $args, array('depth' => $depth, 'max_depth' => $args['max_depth']))) ?>
          </div>
        </div>
      </li>
   
<?php
}


//Code Visual Composer
function theguide_custom_css_classes_for_vc_row_and_vc_column($class_string, $tag) {
    if($tag=='vc_row' || $tag=='vc_row_inner') {
        $class_string = str_replace('vc_row-fluid', '', $class_string);
    }
    if($tag=='vc_column' || $tag=='vc_column_inner') {
    $class_string = preg_replace('/vc_col-sm-12/', 'col-md-12', $class_string);
    $class_string = preg_replace('/vc_col-sm-6/', 'col-md-6', $class_string);
    $class_string = preg_replace('/vc_col-sm-4/', 'col-md-4', $class_string);
    $class_string = preg_replace('/vc_col-sm-3/', 'col-md-3', $class_string);
    $class_string = preg_replace('/vc_col-sm-5/', 'col-md-5', $class_string);
    $class_string = preg_replace('/vc_col-sm-7/', 'col-md-7', $class_string);
    $class_string = preg_replace('/vc_col-sm-8/', 'col-md-8', $class_string);
    $class_string = preg_replace('/vc_col-sm-9/', 'col-md-9', $class_string);
    $class_string = preg_replace('/vc_col-sm-10/', 'col-md-10', $class_string);
    $class_string = preg_replace('/vc_col-sm-11/', 'col-md-11', $class_string);
    $class_string = preg_replace('/vc_col-sm-1/', 'col-md-1', $class_string);
    $class_string = preg_replace('/vc_col-sm-2/', 'col-md-2', $class_string);
    }
    return $class_string;
}
// Filter to Replace default css class for vc_row shortcode and vc_column
add_filter('vc_shortcodes_css_class', 'theguide_custom_css_classes_for_vc_row_and_vc_column', 10, 2); 
// Add new Param in Row
if(function_exists('vc_add_param')){

vc_add_param('vc_row',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Section Title', 'theguide'),
                              "param_name" => "ses_title",
                              "value" => "",
                              "description" => esc_html__("Title of Section, Leave a blank do not show frontend.", "theguide"),   
    )); 
vc_add_param('vc_row',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Section ID', 'theguide'),
                              "param_name" => "ses_id",
                              "value" => "",
                              "description" => esc_html__("ID of Section, Leave a blank do not show frontend.", "theguide"),   
    )); 

vc_add_param('vc_row',array(
                             'type' => 'dropdown',
                             'heading' => esc_html__( 'Chosen type row', 'theguide' ),
                             'param_name' => 'type_row',
                             'value' => array(
                                esc_html__( 'None Section', 'theguide' ) => 'type2', 
                                esc_html__( 'Section Features', 'theguide' ) => 'features',
                                esc_html__( 'Section Pages', 'theguide' ) => 'sec_intro',
                                esc_html__( 'Section Facts', 'theguide' ) => 'sec_fact',
                                esc_html__( 'Code View', 'theguide' ) => 'code_view',
                                esc_html__( 'Section Testimonials', 'theguide' ) => 'testimonials',  
                                esc_html__( 'Section FAQ1', 'theguide' ) => 'faq1', 
                                esc_html__( 'Section FAQ2', 'theguide' ) => 'faq2', 
                             ),
                             'description' => esc_html__( 'Select type row', 'theguide' )
      )); 
vc_add_param('vc_row',array(
                              "type" => "textarea",
                              "heading" => esc_html__('Section Subtitle', 'theguide'),
                              "param_name" => "ses_subtitle",
                              "value" => "",
                              "description" => esc_html__("Section Subtitle, Leave a blank do not show frontend.", "theguide"),   
    ));
vc_add_param('vc_row',array(
                              "type" => "textarea",
                              "heading" => esc_html__('Section Desc', 'theguide'),
                              "param_name" => "ses_desc",
                              "value" => "",
                              "description" => esc_html__("Section Desc, Leave a blank do not show frontend.", "theguide"),   
    ));
vc_add_param('vc_row',array(
                             'type' => 'attach_image',
                             'heading' => esc_html__( 'Image Background', 'theguide' ),
                             'param_name' => 'ses_image',
                             'value' => '',
                             'description' => esc_html__( 'Select image from media library to do your signature.', 'theguide' )
      ));  

// Add new Param in Column  
vc_add_param('vc_column',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Column Title', 'theguide'),
                              "param_name" => "title",
                              "value" => "",
                              "description" => esc_html__("Title of column", "theguide"),      
                            ) 
    );
vc_add_param('vc_column',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Container Class', 'theguide'),
                              "param_name" => "wap_class",
                              "value" => "",
                              "description" => esc_html__("Container Class", "theguide"),      
                            ) 
    );
vc_add_param('vc_column',array(
                              "type" => "textfield",
                              "heading" => esc_html__('Column id', 'theguide'),
                              "param_name" => "column_id",
                              "value" => "",
                              "description" => esc_html__("Column ID, Only use for content slider.", "theguide"),      
                            ) 
    );  
vc_add_param('vc_column',array(
                             'type' => 'dropdown',
                             'heading' => esc_html__( 'Type', 'theguide' ),
                             'param_name' => 'type',
                             'value' => array(
                                esc_html__( 'None', 'theguide' ) => 'none',
                                esc_html__( 'Column', 'theguide' ) => 'column',
                                esc_html__( 'Features Left', 'theguide' ) => 'features_left',
                                esc_html__( 'Features Right', 'theguide' ) => 'features_right',
                                esc_html__( 'Features Icon', 'theguide' ) => 'features_icon',

                             ),
                             'description' => esc_html__( 'Select type section content', 'theguide' )
      )); 

}

/**
 * This file represents an example of the code that themes would use to register
 * the required plugins.
 *
 * It is expected that theme authors would copy and paste this code into their
 * functions.php file, and amend to suit.
 *
 * @package    TGM-Plugin-Activation
 * @subpackage Example
 * @version    2.6.1
 * @author     Thomas Griffin <thomasgriffinmedia.com>
 * @author     Gary Jones <gamajo.com>
 * @copyright  Copyright (c) 2014, Thomas Griffin
 * @license    http://opensource.org/licenses/gpl-2.0.php GPL v2 or later
 * @link       https://github.com/thomasgriffin/TGM-Plugin-Activation
 */
/**
 * Include the TGM_Plugin_Activation class.
 */
require_once get_template_directory() . '/framework/class-tgm-plugin-activation.php';
add_action( 'tgmpa_register', 'theguide_theme_register_required_plugins' );
/**
 * Register the required plugins for this theme.
 *
 * In this example, we register two plugins - one included with the TGMPA library
 * and one from the .org repo.
 *
 * The variable passed to tgmpa_register_plugins() should be an array of plugin
 * arrays.
 *
 * This function is hooked into tgmpa_init, which is fired within the
 * TGM_Plugin_Activation class constructor.
 */
 
 
function theguide_theme_register_required_plugins() {
    /**
     * Array of plugin arrays. Required keys are name and slug.
     * If the source is NOT from the .org repo, then source is also required.
     */
    $plugins = array(
             // This is an example of how to include a plugin from a private repo in your theme.
        array(
            'name'      => esc_html__( 'One Click Demo Import', 'theguide' ),
            'slug'      => 'one-click-demo-import',
            'required'  => true,
        ), 
      array(
            'name'      => esc_html__( 'Classic Editor', 'theguide' ),
            'slug'      => 'classic-editor',
            'required'  => true,
        ), 
      array(
            'name'      => esc_html__( 'Classic Widgets', 'theguide' ),
            'slug'      => 'classic-widgets',
            'required'  => true,
        ),
      array(
            'name'      => esc_html__( 'Contact Form 7', 'theguide' ),
            'slug'      => 'contact-form-7',
            'required'  => true,
        ),
      array(
            'name'      => esc_html__( 'Widget Importer & Exporter', 'theguide' ),
            'slug'      => 'widget-importer-&-exporter',
            'required'  => true,
        ),
      array(
            'name'               => esc_html__( 'WPBakery Visual Composer', 'theguide' ), // The plugin name.
            'slug'               => 'visualcomposer',
            'source'             => get_template_directory_uri() . '/framework/plugins/js_composer.zip', // The plugin source.
            'required'           => true, // If false, the plugin is only 'recommended' instead of required.
        ),
        array(
            'name'               => esc_html__( 'TheGuide Common', 'theguide' ),
            'slug'               => esc_html__( 'theguide-common', 'theguide' ),
            'required'           => true,
            'source'             => get_template_directory() . '/framework/plugins/theguide-common.zip',
        ),
    );
    /**
     * Array of configuration settings. Amend each line as needed.
     * If you want the default strings to be available under your own theme domain,
     * leave the strings uncommented.
     * Some of the strings are added into a sprintf, so see the comments at the
     * end of each line for what each argument will be.
     */
    $config = array(
        'default_path' => '',                      // Default absolute path to pre-packaged plugins.
        'menu'         => 'tgmpa-install-plugins', // Menu slug.
        'has_notices'  => true,                    // Show admin notices or not.
        'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
        'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
        'is_automatic' => false,                   // Automatically activate plugins after installation or not.
        'message'      => '',                      // Message to output right before the plugins table.
        'strings'      => array(
            'page_title'                      => esc_html__( 'Install Required Plugins', 'theguide' ),
            'menu_title'                      => esc_html__( 'Install Plugins', 'theguide' ),
            'installing'                      => esc_html__( 'Installing Plugin: %s', 'theguide' ), // %s = plugin name.
            'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'theguide' ),
            'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'theguide' ), // %1$s = plugin name(s).
            'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'theguide' ), // %1$s = plugin name(s).
            'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'theguide' ), // %1$s = plugin name(s).
            'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'theguide' ), // %1$s = plugin name(s).
            'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'theguide' ), // %1$s = plugin name(s).
            'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'theguide' ), // %1$s = plugin name(s).
            'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'theguide' ), // %1$s = plugin name(s).
            'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'theguide' ), // %1$s = plugin name(s).
            'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'theguide' ),
            'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins', 'theguide' ),
            'return'                          => esc_html__( 'Return to Required Plugins Installer', 'theguide' ),
            'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'theguide' ),
            'complete'                        => esc_html__( 'All plugins installed and activated successfully. %s', 'theguide' ), // %s = dashboard link.
            'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
        )
    );
    tgmpa( $plugins, $config );
}
?>